==> vtk-6.3.0-5-armv6h.pkg.tar.xz: vtk/vtkStreamTracer.java <==
// java wrapper for vtkStreamTracer object
//

package vtk;
import vtk.*;

public class vtkStreamTracer extends vtkPolyDataAlgorithm
{

  private native String GetClassName_0();
  public String GetClassName()
    { return GetClassName_0(); }

  private native int IsA_1(String id0);
  public int IsA(String id0)
    { return IsA_1(id0); }

  private native void SetStartPosition_2(double id0,double id1,double id2);
  public void SetStartPosition(double id0,double id1,double id2)
    { SetStartPosition_2(id0,id1,id2); }

  private native void SetStartPosition_3(double id0[]);
  public void SetStartPosition(double id0[])
    { SetStartPosition_3(id0); }

  private native double[] GetStartPosition_4();
  public double[] GetStartPosition()
    { return GetStartPosition_4(); }

  private native void SetSourceData_5(vtkDataSet id0);
  public void SetSourceData(vtkDataSet id0)
    { SetSourceData_5(id0); }

  private native long GetSource_6();
  public vtkDataSet GetSource() {
    long temp = GetSource_6();

    if (temp == 0) return null;
    return (vtkDataSet)vtkObjectBase.JAVA_OBJECT_MANAGER.getJavaObject(temp);
  }

  private native void SetSourceConnection_7(vtkAlgorithmOutput id0);
  public void SetSourceConnection(vtkAlgorithmOutput id0)
    { SetSourceConnection_7(id0); }

  private native void SetIntegrator_8(vtkInitialValueProblemSolver id0);
  public void SetIntegrator(vtkInitialValueProblemSolver id0)
    { SetIntegrator_8(id0); }

  private native long GetIntegrator_9();
  public vtkInitialValueProblemSolver GetIntegrator() {
    long temp = GetIntegrator_9();

    if (temp == 0) return null;
    return (vtkInitialValueProblemSolver)vtkObjectBase.JAVA_OBJECT_MANAGER.getJavaObject(temp);
  }

  private native void SetIntegratorType_10(int id0);
  public void SetIntegratorType(int id0)
    { SetIntegratorType_10(id0); }

  private native int GetIntegratorType_11();
  public int GetIntegratorType()
    { return GetIntegratorType_11(); }

  private native void SetIntegratorTypeToRungeKutta2_12();
  public void SetIntegratorTypeToRungeKutta2()
    { SetIntegratorTypeToRungeKutta2_12(); }

  private native void SetIntegratorTypeToRungeKutta4_13();
  public void SetIntegratorTypeToRungeKutta4()
    { SetIntegratorTypeToRungeKutta4_13(); }

  private native void SetIntegratorTypeToRungeKutta45_14();
  public void SetIntegratorTypeToRungeKutta45()
    { SetIntegratorTypeToRungeKutta45_14(); }

  private native void SetInterpolatorTypeToDataSetPointLocator_15();
  public void SetInterpolatorTypeToDataSetPointLocator()
    { SetInterpolatorTypeToDataSetPointLocator_15(); }

  private native void SetInterpolatorTypeToCellLocator_16();
  public void SetInterpolatorTypeToCellLocator()
    { SetInterpolatorTypeToCellLocator_16(); }

  private native void SetMaximumPropagation_17(double id0);
  public void SetMaximumPropagation(double id0)
    { SetMaximumPropagation_17(id0); }

  private native double GetMaximumPropagation_18();
  public double GetMaximumPropagation()
    { return GetMaximumPropagation_18(); }

  private native void SetIntegrationStepUnit_19(int id0);
  public void SetIntegrationStepUnit(int id0)
    { SetIntegrationStepUnit_19(id0); }

  private native int GetIntegrationStepUnit_20();
  public int GetIntegrationStepUnit()
    { return GetIntegrationStepUnit_20(); }

  private native void SetInitialIntegrationStep_21(double id0);
  public void SetInitialIntegrationStep(double id0)
    { SetInitialIntegrationStep_21(id0); }

  private native double GetInitialIntegrationStep_22();
  public double GetInitialIntegrationStep()
    { return GetInitialIntegrationStep_22(); }

  private native void SetMinimumIntegrationStep_23(double id0);
  public void SetMinimumIntegrationStep(double id0)
    { SetMinimumIntegrationStep_23(id0); }

  private native double GetMinimumIntegrationStep_24();
  public double GetMinimumIntegrationStep()
    { return GetMinimumIntegrationStep_24(); }

  private native void SetMaximumIntegrationStep_25(double id0);
  public void SetMaximumIntegrationStep(double id0)
    { SetMaximumIntegrationStep_25(id0); }

  private native double GetMaximumIntegrationStep_26();
  public double GetMaximumIntegrationStep()
    { return GetMaximumIntegrationStep_26(); }

  private native void SetMaximumError_27(double id0);
  public void SetMaximumError(double id0)
    { SetMaximumError_27(id0); }

  private native double GetMaximumError_28();
  public double GetMaximumError()
    { return GetMaximumError_28(); }

  private native void SetMaximumNumberOfSteps_29(int id0);
  public void SetMaximumNumberOfSteps(int id0)
    { SetMaximumNumberOfSteps_29(id0); }

  private native int GetMaximumNumberOfSteps_30();
  public int GetMaximumNumberOfSteps()
    { return GetMaximumNumberOfSteps_30(); }

  private native void SetTerminalSpeed_31(double id0);
  public void SetTerminalSpeed(double id0)
    { SetTerminalSpeed_31(id0); }

  private native double GetTerminalSpeed_32();
  public double GetTerminalSpeed()
    { return GetTerminalSpeed_32(); }

  private native boolean GetSurfaceStreamlines_33();
  public boolean GetSurfaceStreamlines()
    { return GetSurfaceStreamlines_33(); }

  private native void SetSurfaceStreamlines_34(boolean id0);
  public void SetSurfaceStreamlines(boolean id0)
    { SetSurfaceStreamlines_34(id0); }

  private native void SurfaceStreamlinesOn_35();
  public void SurfaceStreamlinesOn()
    { SurfaceStreamlinesOn_35(); }

  private native void SurfaceStreamlinesOff_36();
  public void SurfaceStreamlinesOff()
    { SurfaceStreamlinesOff_36(); }

  private native void SetIntegrationDirection_37(int id0);
  public void SetIntegrationDirection(int id0)
    { SetIntegrationDirection_37(id0); }

  private native int GetIntegrationDirectionMinValue_38();
  public int GetIntegrationDirectionMinValue()
    { return GetIntegrationDirectionMinValue_38(); }

  private native int GetIntegrationDirectionMaxValue_39();
  public int GetIntegrationDirectionMaxValue()
    { return GetIntegrationDirectionMaxValue_39(); }

  private native int GetIntegrationDirection_40();
  public int GetIntegrationDirection()
    { return GetIntegrationDirection_40(); }

  private native void SetIntegrationDirectionToForward_41();
  public void SetIntegrationDirectionToForward()
    { SetIntegrationDirectionToForward_41(); }

  private native void SetIntegrationDirectionToBackward_42();
  public void SetIntegrationDirectionToBackward()
    { SetIntegrationDirectionToBackward_42(); }

  private native void SetIntegrationDirectionToBoth_43();
  public void SetIntegrationDirectionToBoth()
    { SetIntegrationDirectionToBoth_43(); }

  private native void SetComputeVorticity_44(boolean id0);
  public void SetComputeVorticity(boolean id0)
    { SetComputeVorticity_44(id0); }

  private native boolean GetComputeVorticity_45();
  public boolean GetComputeVorticity()
    { return GetComputeVorticity_45(); }

  private native void SetRotationScale_46(double id0);
  public void SetRotationScale(double id0)
    { SetRotationScale_46(id0); }

  private native double GetRotationScale_47();
  public double GetRotationScale()
    { return GetRotationScale_47(); }

  private native void SetInterpolatorPrototype_48(vtkAbstractInterpolatedVelocityField id0);
  public void SetInterpolatorPrototype(vtkAbstractInterpolatedVelocityField id0)
    { SetInterpolatorPrototype_48(id0); }

  private native void SetInterpolatorType_49(int id0);
  public void SetInterpolatorType(int id0)
    { SetInterpolatorType_49(id0); }

  public vtkStreamTracer() { super(); }

  public vtkStreamTracer(long id) { super(id); }
  public native long   VTKInit();

}

==> vtk-8.2.0-17-armv6h.pkg.tar.xz: vtk/vtkStreamTracer.java <==
// java wrapper for vtkStreamTracer object
//

package vtk;
import vtk.*;

public class vtkStreamTracer extends vtkPolyDataAlgorithm
{

  private native int IsTypeOf_0(String id0);
  public int IsTypeOf(String id0)
    { return IsTypeOf_0(id0); }

  private native int IsA_1(String id0);
  public int IsA(String id0)
    { return IsA_1(id0); }

  private native void SetStartPosition_2(double id0,double id1,double id2);
  public void SetStartPosition(double id0,double id1,double id2)
    { SetStartPosition_2(id0,id1,id2); }

  private native void SetStartPosition_3(double id0[]);
  public void SetStartPosition(double id0[])
    { SetStartPosition_3(id0); }

  private native double[] GetStartPosition_4();
  public double[] GetStartPosition()
    { return GetStartPosition_4(); }

  private native void SetSourceData_5(vtkDataSet id0);
  public void SetSourceData(vtkDataSet id0)
    { SetSourceData_5(id0); }

  private native long GetSource_6();
  public vtkDataSet GetSource() {
    long temp = GetSource_6();

    if (temp == 0) return null;
    return (vtkDataSet)vtkObjectBase.JAVA_OBJECT_MANAGER.getJavaObject(temp);
}

  private native void SetSourceConnection_7(vtkAlgorithmOutput id0);
  public void SetSourceConnection(vtkAlgorithmOutput id0)
    { SetSourceConnection_7(id0); }

  private native void SetIntegrator_8(vtkInitialValueProblemSolver id0);
  public void SetIntegrator(vtkInitialValueProblemSolver id0)
    { SetIntegrator_8(id0); }

  private native long GetIntegrator_9();
  public vtkInitialValueProblemSolver GetIntegrator() {
    long temp = GetIntegrator_9();

    if (temp == 0) return null;
    return (vtkInitialValueProblemSolver)vtkObjectBase.JAVA_OBJECT_MANAGER.getJavaObject(temp);
}

  private native void SetIntegratorType_10(int id0);
  public void SetIntegratorType(int id0)
    { SetIntegratorType_10(id0); }

  private native int GetIntegratorType_11();
  public int GetIntegratorType()
    { return GetIntegratorType_11(); }

  private native void SetIntegratorTypeToRungeKutta2_12();
  public void SetIntegratorTypeToRungeKutta2()
    { SetIntegratorTypeToRungeKutta2_12(); }

  private native void SetIntegratorTypeToRungeKutta4_13();
  public void SetIntegratorTypeToRungeKutta4()
    { SetIntegratorTypeToRungeKutta4_13(); }

  private native void SetIntegratorTypeToRungeKutta45_14();
  public void SetIntegratorTypeToRungeKutta45()
    { SetIntegratorTypeToRungeKutta45_14(); }

  private native void SetInterpolatorTypeToDataSetPointLocator_15();
  public void SetInterpolatorTypeToDataSetPointLocator()
    { SetInterpolatorTypeToDataSetPointLocator_15(); }

  private native void SetInterpolatorTypeToCellLocator_16();
  public void SetInterpolatorTypeToCellLocator()
    { SetInterpolatorTypeToCellLocator_16(); }

  private native void SetMaximumPropagation_17(double id0);
  public void SetMaximumPropagation(double id0)
    { SetMaximumPropagation_17(id0); }

  private native double GetMaximumPropagation_18();
  public double GetMaximumPropagation()
    { return GetMaximumPropagation_18(); }

  private native void SetIntegrationStepUnit_19(int id0);
  public void SetIntegrationStepUnit(int id0)
    { SetIntegrationStepUnit_19(id0); }

  private native int GetIntegrationStepUnit_20();
  public int GetIntegrationStepUnit()
    { return GetIntegrationStepUnit_20(); }

  private native void SetInitialIntegrationStep_21(double id0);
  public void SetInitialIntegrationStep(double id0)
    { SetInitialIntegrationStep_21(id0); }

  private native double GetInitialIntegrationStep_22();
  public double GetInitialIntegrationStep()
    { return GetInitialIntegrationStep_22(); }

  private native void SetMinimumIntegrationStep_23(double id0);
  public void SetMinimumIntegrationStep(double id0)
    { SetMinimumIntegrationStep_23(id0); }

  private native double GetMinimumIntegrationStep_24();
  public double GetMinimumIntegrationStep()
    { return GetMinimumIntegrationStep_24(); }

  private native void SetMaximumIntegrationStep_25(double id0);
  public void SetMaximumIntegrationStep(double id0)
    { SetMaximumIntegrationStep_25(id0); }

  private native double GetMaximumIntegrationStep_26();
  public double GetMaximumIntegrationStep()
    { return GetMaximumIntegrationStep_26(); }

  private native void SetMaximumError_27(double id0);
  public void SetMaximumError(double id0)
    { SetMaximumError_27(id0); }

  private native double GetMaximumError_28();
  public double GetMaximumError()
    { return GetMaximumError_28(); }

  private native void SetMaximumNumberOfSteps_29(int id0);
  public void SetMaximumNumberOfSteps(int id0)
    { SetMaximumNumberOfSteps_29(id0); }

  private native int GetMaximumNumberOfSteps_30();
  public int GetMaximumNumberOfSteps()
    { return GetMaximumNumberOfSteps_30(); }

  private native void SetTerminalSpeed_31(double id0);
  public void SetTerminalSpeed(double id0)
    { SetTerminalSpeed_31(id0); }

  private native double GetTerminalSpeed_32();
  public double GetTerminalSpeed()
    { return GetTerminalSpeed_32(); }

  private native boolean GetSurfaceStreamlines_33();
  public boolean GetSurfaceStreamlines()
    { return GetSurfaceStreamlines_33(); }

  private native void SetSurfaceStreamlines_34(boolean id0);
  public void SetSurfaceStreamlines(boolean id0)
    { SetSurfaceStreamlines_34(id0); }

  private native void SurfaceStreamlinesOn_35();
  public void SurfaceStreamlinesOn()
    { SurfaceStreamlinesOn_35(); }

  private native void SurfaceStreamlinesOff_36();
  public void SurfaceStreamlinesOff()
    { SurfaceStreamlinesOff_36(); }

  private native void SetIntegrationDirection_37(int id0);
  public void SetIntegrationDirection(int id0)
    { SetIntegrationDirection_37(id0); }

  private native int GetIntegrationDirectionMinValue_38();
  public int GetIntegrationDirectionMinValue()
    { return GetIntegrationDirectionMinValue_38(); }

  private native int GetIntegrationDirectionMaxValue_39();
  public int GetIntegrationDirectionMaxValue()
    { return GetIntegrationDirectionMaxValue_39(); }

  private native int GetIntegrationDirection_40();
  public int GetIntegrationDirection()
    { return GetIntegrationDirection_40(); }

  private native void SetIntegrationDirectionToForward_41();
  public void SetIntegrationDirectionToForward()
    { SetIntegrationDirectionToForward_41(); }

  private native void SetIntegrationDirectionToBackward_42();
  public void SetIntegrationDirectionToBackward()
    { SetIntegrationDirectionToBackward_42(); }

  private native void SetIntegrationDirectionToBoth_43();
  public void SetIntegrationDirectionToBoth()
    { SetIntegrationDirectionToBoth_43(); }

  private native void SetComputeVorticity_44(boolean id0);
  public void SetComputeVorticity(boolean id0)
    { SetComputeVorticity_44(id0); }

  private native boolean GetComputeVorticity_45();
  public boolean GetComputeVorticity()
    { return GetComputeVorticity_45(); }

  private native void SetRotationScale_46(double id0);
  public void SetRotationScale(double id0)
    { SetRotationScale_46(id0); }

  private native double GetRotationScale_47();
  public double GetRotationScale()
    { return GetRotationScale_47(); }

  private native void SetInterpolatorPrototype_48(vtkAbstractInterpolatedVelocityField id0);
  public void SetInterpolatorPrototype(vtkAbstractInterpolatedVelocityField id0)
    { SetInterpolatorPrototype_48(id0); }

  private native void SetInterpolatorType_49(int id0);
  public void SetInterpolatorType(int id0)
    { SetInterpolatorType_49(id0); }

  public vtkStreamTracer() { super(); }

  public vtkStreamTracer(long id) { super(id); }
  public native long   VTKInit();

}
